@@ -22,7 +22,7 @@ data("wbttoolparameters", package="whitebox")
 # }
 
 # system and package dependencies must be met to build the vignette
-stopifnot(requireNamespace("raster"))
+stopifnot(requireNamespace("terra"))
 
 ## -----------------------------------------------------------------------------
 library(whitebox)
@@ -31,7 +31,7 @@ library(whitebox)
 wbt_exe_path(shell_quote = FALSE)
 
 ## -----------------------------------------------------------------------------
-library(raster)
+library(terra)
 library(whitebox)
 
 # DEMO: calculate slope with WhiteboxTools and raster
@@ -49,8 +49,8 @@ wbt_slope(input, output, units = 'radians')
 
 ## -----------------------------------------------------------------------------
 if (file.exists(output)) {
-  # create a RasterLayer from file output path
-  outputras <- raster::raster(output)
+  # create a SpatRaster from file output path
+  outputras <- terra::rast(output)
 }
 
 ## -----------------------------------------------------------------------------
@@ -58,23 +58,24 @@ if (file.exists(output)) {
   # par(mfrow = c(2, 1), mar = c(1, 1, 1, 1))
   
   # inspect the output graphically
-  raster::plot(
+  plot(
     outputras,
     main = "whitebox::wbt_slope() [radians]",
-    axes = FALSE, horizontal = TRUE
+    axes = FALSE
   )
   
   # calculate equivalent using raster::terrain() on input
-  raster::plot(
-    raster::terrain(raster::raster(input, crs = "EPSG:26918")),
-    main = "raster::terrain() [radians]",
-    axes = FALSE, horizontal = TRUE
+  plot(
+    terra::terrain(set.crs(terra::rast(input), "EPSG:26918")),
+    main = "terra::terrain() [radians]",
+    axes = FALSE
   )
-
-# the RasterLayer retains a reference to the input file name
-raster::filename(outputras)
 }
 
+## -----------------------------------------------------------------------------
+# the SpatRaster retains a reference to the input file name
+terra::sources(outputras)
+
 ## -----------------------------------------------------------------------------
 # inspect where wbt_init() will be checking
 wbt_exe_path(shell_quote = FALSE)
@@ -112,7 +113,7 @@ output <- file.path(tempdir(), "output.tif")
 wbt_run_tool(tool_name = "BreachDepressions", args = paste0("--dem=", input, " --output=", output))
 
 ## -----------------------------------------------------------------------------
-library(raster)
+library(terra)
 
 # sample DEM file path in package extdata folder
 input <- sample_dem_data()
@@ -126,31 +127,28 @@ wbt_breach_depressions(dem = input, output = output)
 
 ## -----------------------------------------------------------------------------
 # create raster object from input file
-input <- raster(input)
+input <- rast(input)
 
 if (file.exists(output)) {
   # create raster object from output file
-  output <- raster(output)
+  output <- rast(output)
   
   # par(mar = c(2, 1, 2, 1))
   # inspect input v.s. output
-  plot(input, axes = FALSE, horizontal = TRUE, box = FALSE, main = "DEM")
-  plot(output, axes = FALSE, horizontal = TRUE, box = FALSE, 
-       main = "DEM (Breached Depressions)")
+  plot(input, axes = FALSE, main = "DEM")
+  plot(output, axes = FALSE, main = "DEM (Breached Depressions)")
   
   # inspect numeric difference (output - input) 
-  plot(output - input, axes = FALSE, horizontal = TRUE, box = FALSE, 
-       main = "Difference ([Breached Depressions] - [DEM])")
+  plot(output - input, axes = FALSE,  main = "Difference ([Breached Depressions] - [DEM])")
 }
 
 ## -----------------------------------------------------------------------------
 library(whitebox)
-library(raster)
+library(terra)
 
 ## Sample DEM from whitebox package
 toy_file <- sample_dem_data()
-toy_dem <- raster(x = toy_file, values = TRUE)
-crs(toy_dem) <- "EPSG:26918"
+toy_dem <- set.crs(rast(x = toy_file), "EPSG:26918")
 
 ## Generate wd as a temporary directory. 
 ## Replace with your own path, or "." for current directory
@@ -208,7 +206,7 @@ if (file.exists(file.path(wd, "toy_dem_streams.tif"))) {
   # par(mfrow = c(2, 1), mar = c(3, 1, 2, 1))
   
   plot(
-    raster(file.path(wd, "toy_dem_streams.tif")),
+    rast(file.path(wd, "toy_dem_streams.tif")),
     main = "Streams",
     col = "black",
     axes = FALSE,
@@ -217,7 +215,7 @@ if (file.exists(file.path(wd, "toy_dem_streams.tif"))) {
   )
   
   plot(
-    raster(file.path(wd, "toy_dem_tributaries.tif")),
+    rast(file.path(wd, "toy_dem_tributaries.tif")),
     main = "TributaryIdentifier",
     axes = FALSE,
     horizontal = TRUE,
