@@ -4,7 +4,7 @@ test_that("Rounds the values in an input raster to the nearest integer value", {
 
   skip_on_cran()
   skip_if_not(check_whitebox_binary())
-  dem <- system.file("extdata", "DEM.tif", package = "whitebox")
+  dem <- sample_dem_data(); skip_if(dem == "")
   ret <- wbt_round(input = dem, output = "output.tif")
   expect_match(ret, "Elapsed Time")
 
